@@ -227,14 +227,16 @@ sub parse_oldstyle_line
 
         if ($hash->{passthru}) {
                 if ($hash->{passthru} =~ /^(shade|color|colour)$/i) {
-                        if ($hash->{body} =~ /^\s*(\d+)\s+(\d+)\s+(\d+)/) {
+                        if ($hash->{body} =~ /^\s*(\d+)\s+(\d+)\s+(\d+)\s*(.*)/) {
                                 $hash->{r} = $1;
                                 $hash->{g} = $2;
                                 $hash->{b} = $3;
-                        } elsif ($hash->{body} =~ /^\s*(\d+)/) {
+                                $hash->{body} = $4;
+                        } elsif ($hash->{body} =~ /^\s*(\d+)\s*(.*)/) {
                                 $hash->{r} = $1;
                                 $hash->{g} = $1;
                                 $hash->{b} = $1;
+                                $hash->{body} = $2;
                         }
                 }
         }
@@ -285,7 +287,7 @@ sub read_one_month_pp
 Given a hashref C<$hash> consisting of one entry parsed
 from the "remind -p" stream and a C<$specials_accepted> hash,
 return 1 if we should include this entry in the calendar or
-0 if mot.
+0 if not.
 
 =cut
 sub accept_special
